==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1beta1/Metal3RemediationStatusFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class Metal3RemediationStatusFluent<A extends Metal3RemediationStatusFluent<A>> extends BaseFluent<A>{
  public Metal3RemediationStatusFluent() {
  }
  
  public Metal3RemediationStatusFluent(Metal3RemediationStatus instance) {
    this.copyInstance(instance);
  }
  private String lastRemediated;
  private String phase;
  private Integer retryCount;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Metal3RemediationStatus instance) {
    instance = (instance != null ? instance : new Metal3RemediationStatus());
  
    if (instance != null) {
        this.withLastRemediated(instance.getLastRemediated());
        this.withPhase(instance.getPhase());
        this.withRetryCount(instance.getRetryCount());
        this.withLastRemediated(instance.getLastRemediated());
        this.withPhase(instance.getPhase());
        this.withRetryCount(instance.getRetryCount());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getLastRemediated() {
    return this.lastRemediated;
  }
  
  public A withLastRemediated(String lastRemediated) {
    this.lastRemediated=lastRemediated; return (A) this;
  }
  
  public boolean hasLastRemediated() {
    return this.lastRemediated != null;
  }
  
  public String getPhase() {
    return this.phase;
  }
  
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  
  public boolean hasPhase() {
    return this.phase != null;
  }
  
  public Integer getRetryCount() {
    return this.retryCount;
  }
  
  public A withRetryCount(Integer retryCount) {
    this.retryCount=retryCount; return (A) this;
  }
  
  public boolean hasRetryCount() {
    return this.retryCount != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    Metal3RemediationStatusFluent that = (Metal3RemediationStatusFluent) o;
    if (!java.util.Objects.equals(lastRemediated, that.lastRemediated)) return false;
  
    if (!java.util.Objects.equals(phase, that.phase)) return false;
  
    if (!java.util.Objects.equals(retryCount, that.retryCount)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(lastRemediated,  phase,  retryCount,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastRemediated != null) { sb.append("lastRemediated:"); sb.append(lastRemediated + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (retryCount != null) { sb.append("retryCount:"); sb.append(retryCount + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-miscellaneous-6.9.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1beta1/Metal3RemediationStatusFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class Metal3RemediationStatusFluent<A extends Metal3RemediationStatusFluent<A>> extends BaseFluent<A>{
  public Metal3RemediationStatusFluent() {
  }
  
  public Metal3RemediationStatusFluent(Metal3RemediationStatus instance) {
    this.copyInstance(instance);
  }
  private String lastRemediated;
  private String phase;
  private Integer retryCount;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Metal3RemediationStatus instance) {
    instance = (instance != null ? instance : new Metal3RemediationStatus());
    if (instance != null) {
          this.withLastRemediated(instance.getLastRemediated());
          this.withPhase(instance.getPhase());
          this.withRetryCount(instance.getRetryCount());
          this.withLastRemediated(instance.getLastRemediated());
          this.withPhase(instance.getPhase());
          this.withRetryCount(instance.getRetryCount());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getLastRemediated() {
    return this.lastRemediated;
  }
  
  public A withLastRemediated(String lastRemediated) {
    this.lastRemediated = lastRemediated;
    return (A) this;
  }
  
  public boolean hasLastRemediated() {
    return this.lastRemediated != null;
  }
  
  public String getPhase() {
    return this.phase;
  }
  
  public A withPhase(String phase) {
    this.phase = phase;
    return (A) this;
  }
  
  public boolean hasPhase() {
    return this.phase != null;
  }
  
  public Integer getRetryCount() {
    return this.retryCount;
  }
  
  public A withRetryCount(Integer retryCount) {
    this.retryCount = retryCount;
    return (A) this;
  }
  
  public boolean hasRetryCount() {
    return this.retryCount != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    Metal3RemediationStatusFluent that = (Metal3RemediationStatusFluent) o;
    if (!java.util.Objects.equals(lastRemediated, that.lastRemediated)) return false;
    if (!java.util.Objects.equals(phase, that.phase)) return false;
    if (!java.util.Objects.equals(retryCount, that.retryCount)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(lastRemediated,  phase,  retryCount,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastRemediated != null) { sb.append("lastRemediated:"); sb.append(lastRemediated + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (retryCount != null) { sb.append("retryCount:"); sb.append(retryCount + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
